@@ -25,7 +25,7 @@
 #define KEYB_RED "#eeaaaa"
 #define KEYB_BLUE "#bbbbff"
 #define KEYB_YELLOW "#eeee88"
-#define KEYB_ORANGE "#ffdd88"
+#define KEYB_ORANGE "#ffcc77" /* "#ffdd88" */
 #define KEYB_PURPLE "#ccaacc"
 #define KEYB_BLACK "#000000"
 
