@@ -526,6 +526,7 @@ plot_draw_chart (gint field)
 		gdk_color_parse (PLOT_GREEN_3, &color3);
 		break;
 	case 2:
+		plot.lim.y[1] = 120;
 		plot.goal.y[0] = tutor_goal_speed ();
 		gdk_color_parse (PLOT_RED, &color);
 		gdk_color_parse (PLOT_RED_2, &color2);
@@ -584,6 +585,8 @@ plot_draw_chart (gint field)
 	gdk_color_parse ("#dddddd", &color);
 	if (field == 1)
 		plot.grid = gtk_databox_grid_new (3, 3, &color, 1);
+	else if (field == 2)
+		plot.grid = gtk_databox_grid_new (11, 3, &color, 1);
 	else
 		plot.grid = gtk_databox_grid_new (9, 3, &color, 1);
 	gtk_databox_graph_add (GTK_DATABOX (plot.databox), plot.grid);
