@@ -15,6 +15,7 @@
  */
 #include <stdio.h>
 #include <string.h>
+#include <locale.h>
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <gtk/gtk.h>
@@ -61,7 +62,7 @@ trans_code_to_country (gchar *code)
 		{"it","Italia"},
 		{"jp","日本 (Nippon)"},
 		{"kk","Қазақстан"},
-		{"nb","Norge"},
+		{"no","Norge"},
 		{"pl","Polska"},
 		{"pk","پاکستان"},
 		{"pt","Portugal"},
@@ -72,7 +73,7 @@ trans_code_to_country (gchar *code)
 		{"uk","United Kingdom"},
 		{"us","USA"},
 		{"cn","中华人民共和国"},
-		{"",""},
+		{"ch","Schweiz / Suisse"},
 		{"",""},
 		{"",""},
 		{"",""},
@@ -298,8 +299,8 @@ trans_init_language_env ()
 		/* 
 		 * Read the current locale
 		 */
-#ifdef G_OS_UNIX
 		i = 0;
+#ifdef G_OS_UNIX
 		while ((tmp_code = g_strdup (g_get_language_names ()[i])))
 		{
 			if (tmp_code[0] == 'C')
@@ -403,7 +404,6 @@ trans_set_combo_language ()
 	else
 		gtk_combo_box_set_active (cmb, i_env);
 
-	g_free (tmp_code);
 
 	callbacks_shield_set (FALSE);
 
@@ -414,6 +414,18 @@ trans_set_combo_language ()
 		return;
 	}
 	recur = FALSE;
+
+	if (tmp_code[0] == 'C')
+	{
+		g_free (tmp_code);
+		tmp_code = g_strdup ("en");
+	}
+	if (tmp_code[0] == _("en")[0] && tmp_code[1] == _("en")[1])
+		gtk_widget_show (get_wg ("checkbutton_speech"));
+	else
+		gtk_widget_hide (get_wg ("checkbutton_speech"));
+
+	g_free (tmp_code);
 }
 
 /**********************************************************************
@@ -450,6 +462,7 @@ void
 trans_change_language (gchar *language)
 {
 	gint i;
+	gchar *tmp_code;
 
 	for (i = 0; i < lang_num; i++)
 		if (g_str_has_prefix (language, lang[i].name))
@@ -466,7 +479,18 @@ trans_change_language (gchar *language)
 	velo_reset_dict ();
 	fluid_reset_paragraph ();
 
-	//gtk_widget_hide (get_wg ("window_top10"));
+	/* Check if the interface language is the same of the selected in the combo,
+	 * so that it may be spoken
+	 */
+	if (lang[i].code[0] == 'C')
+		tmp_code = g_strdup ("en");
+	else
+		tmp_code = g_strdup (lang[i].code);
+	if (tmp_code[0] == _("en")[0] && tmp_code[1] == _("en")[1])
+		gtk_widget_show (get_wg ("checkbutton_speech"));
+	else
+		gtk_widget_hide (get_wg ("checkbutton_speech"));
+	g_free (tmp_code);
 }
 
 /**********************************************************************
