@@ -295,12 +295,10 @@ tutor_update ()
 		break;
 
 	case QUERY_PROCESS_TOUCHS:
-		//gtk_widget_set_sensitive (get_wg ("button_tutor_restart"), TRUE);
 		break;
 
 	case QUERY_END:
 		tutor_message (_("End of exercise. Press [Enter] to start another."));
-		//gtk_widget_set_sensitive (get_wg ("button_tutor_restart"), FALSE);
 		break;
 	}
 }
@@ -333,8 +331,6 @@ tutor_update_intro ()
 
 	tutor_message (_("Press any key to start the exercise. "));
 
-	//gtk_widget_set_sensitive (get_wg ("button_tutor_restart"), FALSE);
-
 	tmp_name = g_strconcat ("_", tutor_get_type_name (), "_intro.txt", NULL);
 	text = trans_read_text (tmp_name);
 	g_free (tmp_name);
@@ -440,7 +436,14 @@ tutor_update_start ()
 		start = end;
 	}
 	
-	tutor_message (_("Start typing when you are ready. "));
+	if (tutor.type == TT_FLUID)
+		tmp_name = g_strconcat (_("Start typing when you are ready. "), " ",
+			       _("Use backspace to correct errors."), " ", NULL);
+	else
+		tmp_name = g_strdup (_("Start typing when you are ready. "));
+
+	tutor_message (tmp_name);
+	g_free (tmp_name);
 
 	wg = get_wg ("scrolledwindow_tutor_main");
 	scroll = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (wg));
@@ -505,7 +508,6 @@ tutor_process_touch (gunichar user_chr)
 
 	case QUERY_START:
 		tutor.query = QUERY_PROCESS_TOUCHS;
-		tutor_update ();
 		callbacks_shield_set (TRUE);
 		u8ch = g_malloc0 (7);
 		if (g_unichar_to_utf8 (user_chr, u8ch) > 0)
@@ -553,8 +555,7 @@ tutor_process_touch (gunichar user_chr)
 		return;
 	}
 
-	/*
-	 * It is time to analise the correctness of typing.
+	/* It is time to analise the correctness of typing.
 	 */
 	if (tutor.type == TT_FLUID)
 		go_on = tutor_eval_forward_backward (user_chr);
@@ -574,21 +575,23 @@ tutor_process_touch (gunichar user_chr)
 	}
 	else
 	{
-		cursor_on (NULL);
-
 		switch (tutor.type)
 		{
 		case TT_BASIC:
+			cursor_on (NULL);
 			hints_update_from_char (cursor_get_char ());
 			tutor_speak_char ();
 			return;
 		case TT_ADAPT:
+			cursor_on (NULL);
 			tutor_speak_char ();
 			return;
 		case TT_VELO:
+			cursor_on (NULL);
 			tutor_speak_word ();
 			return;
 		case TT_FLUID:
+			cursor_off (NULL);
 			return;
 		}
 	}
